@@ -1,6 +1,6 @@
 ##############################################################################
 #
-# Copyright (c) 2006 Zope Corporation and Contributors.
+# Copyright (c) 2006 Zope Foundation and Contributors.
 # All Rights Reserved.
 #
 # This software is subject to the provisions of the Zope Public License,
@@ -13,14 +13,14 @@
 ##############################################################################
 """Testing for z3c.etestbrowser
 
-$Id: tests.py 75762 2007-05-15 14:27:59Z ctheune $
+$Id: tests.py 114339 2010-07-08 16:25:22Z tlotze $
 """
 
+import doctest
 import os.path
 import unittest
 
 from zope.app.testing import functional
-from zope.testing import doctest
 
 
 layer = functional.ZCMLLayer(
@@ -32,6 +32,7 @@ def test_suite():
     suite = unittest.TestSuite()
     test = functional.FunctionalDocFileSuite(
         "README.txt",
+        "over_the_wire.txt",
         optionflags=doctest.REPORT_NDIFF|doctest.NORMALIZE_WHITESPACE|
         doctest.ELLIPSIS)
     test.layer = layer
